@@ -1,22 +1,24 @@
-# mypy: ignore-errors
+from typing import Any, Optional
 
 import torch
 
-from pytorch_pfn_extras.nn.modules.lazy import LazyInitializationMixin
-from pytorch_pfn_extras.nn.modules.lazy import UninitializedParameter
+from pytorch_pfn_extras.nn.modules.lazy import (
+    LazyInitializationMixin, UninitializedParameter
+)
 
 
 class _LazyConvNd(LazyInitializationMixin):
 
     lazy_parameter_names = ('weight',)
 
-    def __init__(self, in_channels, *args, **kwargs):
+    def __init__(
+            self: Any, in_channels: Optional[int], *args: Any, **kwargs: Any) -> None:
         super().__init__(in_channels or 0, *args, **kwargs)
         if in_channels is None:
-            self.in_channels = None
+            self.in_channels: Optional[int] = None
             self.weight = UninitializedParameter()
 
-    def forward(self, input):
+    def forward(self: Any, input: torch.Tensor) -> torch.Tensor:
         if isinstance(self.weight, UninitializedParameter):
             self.in_channels = input.shape[1]
             if self.transposed:
@@ -27,16 +29,16 @@ class _LazyConvNd(LazyInitializationMixin):
                          *self.kernel_size)
             self.weight = torch.nn.Parameter(self.weight.new_empty(*shape))
             self.reset_parameters()
-        return super().forward(input)
+        return super().forward(input)  # type: ignore
 
-    def reset_parameters(self):
+    def reset_parameters(self: Any) -> None:
         # Defer initialization of parameters until shape of all parameters
         # are ready.
         if self.lazy_parmeters_determined:
-            super().reset_parameters()
+            super().reset_parameters()  # type: ignore[misc]
 
 
-class LazyConv1d(_LazyConvNd, torch.nn.Conv1d):
+class LazyConv1d(_LazyConvNd, torch.nn.Conv1d):  # type: ignore[misc]
     """Conv1d module with lazy weight initialization.
 
     When ``in_channels`` is ``None``, it is determined at the first time of
@@ -45,7 +47,7 @@ class LazyConv1d(_LazyConvNd, torch.nn.Conv1d):
     pass
 
 
-class LazyConv2d(_LazyConvNd, torch.nn.Conv2d):
+class LazyConv2d(_LazyConvNd, torch.nn.Conv2d):  # type: ignore[misc]
     """Conv2d module with lazy weight initialization.
 
     When ``in_channels`` is ``None``, it is determined at the first time of
@@ -54,7 +56,7 @@ class LazyConv2d(_LazyConvNd, torch.nn.Conv2d):
     pass
 
 
-class LazyConv3d(_LazyConvNd, torch.nn.Conv3d):
+class LazyConv3d(_LazyConvNd, torch.nn.Conv3d):  # type: ignore[misc]
     """Conv3d module with lazy weight initialization.
 
     When ``in_channels`` is ``None``, it is determined at the first time of
