@@ -74,14 +74,14 @@ def _type_to_proto(t: torch._C.TensorType) -> onnx.TypeProto:
         return ret
 
     if t.kind() == "IntType":
-        ret.tensor_type.elem_type = onnx.TensorProto.DataType.INT64
+        ret.tensor_type.elem_type = onnx.TensorProto.DataType.INT64  # type: ignore[attr-defined]
         ret.tensor_type.shape.CopyFrom(onnx.TensorShapeProto())
         return ret
 
     assert t.kind() == "TensorType", f"Not Tensor type(actual: {t.kind()}): {t}"
 
     if t.scalarType() is None:
-        ret.tensor_type.elem_type = onnx.TensorProto.DataType.UNDEFINED
+        ret.tensor_type.elem_type = onnx.TensorProto.DataType.UNDEFINED  # type: ignore[attr-defined]
     else:
         ret.tensor_type.elem_type = int(  # type: ignore
             sym_hel.cast_pytorch_to_onnx[t.scalarType()]  # type: ignore[index]
@@ -124,15 +124,17 @@ def onnx_node_doc_string(onnx_node: torch._C.Node, torch_node: torch._C.Node) ->
 
 
 torch_dtype_to_onnx_data_type = {
-    torch.float32: onnx.TensorProto.DataType.FLOAT,
-    torch.uint8: onnx.TensorProto.DataType.UINT8,
-    torch.int8: onnx.TensorProto.DataType.INT8,
-    torch.int16: onnx.TensorProto.DataType.INT16,
-    torch.int32: onnx.TensorProto.DataType.INT32,
-    torch.int64: onnx.TensorProto.DataType.INT64,
-    torch.bool: onnx.TensorProto.DataType.BOOL,
-    torch.float64: onnx.TensorProto.DataType.DOUBLE,
-    torch.float16: onnx.TensorProto.DataType.FLOAT16,
+    torch.float32: onnx.TensorProto.DataType.FLOAT,  # type: ignore[attr-defined]
+    torch.uint8: onnx.TensorProto.DataType.UINT8,  # type: ignore[attr-defined]
+    torch.int8: onnx.TensorProto.DataType.INT8,  # type: ignore[attr-defined]
+    torch.int16: onnx.TensorProto.DataType.INT16,  # type: ignore[attr-defined]
+    torch.int32: onnx.TensorProto.DataType.INT32,  # type: ignore[attr-defined]
+    torch.int64: onnx.TensorProto.DataType.INT64,  # type: ignore[attr-defined]
+    torch.bool: onnx.TensorProto.DataType.BOOL,  # type: ignore[attr-defined]
+    torch.float64: onnx.TensorProto.DataType.DOUBLE,  # type: ignore[attr-defined]
+    torch.float16: onnx.TensorProto.DataType.FLOAT16,  # type: ignore[attr-defined]
+    torch.complex64: onnx.TensorProto.DataType.COMPLEX64,  # type: ignore[attr-defined]
+    torch.complex128: onnx.TensorProto.DataType.COMPLEX128,  # type: ignore[attr-defined]
 }
 
 
@@ -165,6 +167,7 @@ class _ExporterOptions:
     onnx_data_prop: bool = True
     onnx_lowprecision_cast: bool = True
     onnx_peephole: bool = True
+    onnx_scalar_type_analysis: bool = True
     fixed_batch_size: bool = False
 
     input_names: Optional[List[str]] = None
@@ -339,10 +342,11 @@ class _Exporter(_ExporterOptions):
 
     # ONNX level graph optimizer
     def optimize_onnx(self, graph: torch._C.Graph) -> torch._C.Graph:
-        if pytorch_pfn_extras.requires("1.9.0"):
-            run_jit_pass(torch._C._jit_pass_onnx_scalar_type_analysis, graph, self.onnx_lowprecision_cast, self.opset_version)
-        else:
-            run_jit_pass(torch._C._jit_pass_onnx_scalar_type_analysis, graph)
+        if self.onnx_scalar_type_analysis:
+            if pytorch_pfn_extras.requires("1.9.0"):
+                run_jit_pass(torch._C._jit_pass_onnx_scalar_type_analysis, graph, self.onnx_lowprecision_cast, self.opset_version)
+            else:
+                run_jit_pass(torch._C._jit_pass_onnx_scalar_type_analysis, graph)
 
         if self.do_constant_folding and self.opset_version in pytorch_pfn_extras.onnx._constants.onnx_constant_folding_opsets:
             folded: Dict[str, torch.IValue] = torch._C._jit_pass_onnx_constant_fold(  # type: ignore[attr-defined]
@@ -835,8 +839,8 @@ class _Exporter(_ExporterOptions):
         def onnx_value(v: torch._C.Value, name: ONNXValueID) -> onnx.ValueInfoProto:
             return onnx.helper.make_value_info(
                 name,
-                None if v.type() is None else _type_to_proto(cast(torch._C.TensorType, v.type())),
-                doc_string=None if self.strip_doc_string else repr(v),
+                onnx.TypeProto() if v.type() is None else _type_to_proto(cast(torch._C.TensorType, v.type())),
+                doc_string="" if self.strip_doc_string else repr(v),
             )
 
         def apply_dynamic_axes_info(out: onnx.ValueInfoProto, k: str) -> None:
