@@ -463,7 +463,7 @@ class _BaseExtensionsManager:
             # Some mock objects for tests give errors
             # if we use `getattr`
             try:
-                if entry.extension.finalize:
+                if entry.extension.finalize:  # type: ignore[truthy-function]
                     entry.extension.finalize(self)
             except AttributeError:
                 pass
