@@ -1,4 +1,5 @@
 import unittest.mock
+import contextlib
 
 import torch
 import pytest
@@ -71,6 +72,12 @@ class MockRuntime(ppe.runtime.BaseRuntime):
         self._eval_post_step_called = True
         self._called_module = module
 
+    @classmethod
+    @contextlib.contextmanager
+    def trace(cls, event_name, arg):
+        arg["called"] = True
+        yield
+
 
 class MockModule(torch.nn.Module):
     def __init__(self):
@@ -280,10 +287,9 @@ class TestHandlerValidationSync(HandlerTester):
 
 @pytest.mark.gpu
 class TestHandlerAutocast:
-    @pytest.mark.parametrize('autocast', [True, False])
-    def test_autocast(self, autocast):
+    def run_autocast(self, options):
         trainer = MockTrainer()
-        logic = ppe.handler.Logic(options={'autocast': autocast})
+        logic = ppe.handler.Logic(options=options)
         handler = ppe.handler.Handler(
             logic, ppe.runtime.PyTorchRuntime('cuda', {}), {}
         )
@@ -303,10 +309,16 @@ class TestHandlerAutocast:
 
         def callback(batch_idx, outs):
             nonlocal completed
-            if autocast:
-                assert outs.dtype == torch.float16
-            else:
-                assert outs.dtype == torch.float32
+            if "autocast" in options:
+                if isinstance(options["autocast"], bool):
+                    if options["autocast"]:
+                        assert outs.dtype == torch.float16
+                    else:
+                        assert outs.dtype == torch.float32
+                else:
+                    if options["autocast"]["device_type"] == "cuda":
+                        assert outs.dtype == options["autocast"]["dtype"]
+                    # For some reason result for CPU is float32 instead of bfloat16
             completed = True
 
         inputs = {
@@ -316,14 +328,28 @@ class TestHandlerAutocast:
         handler.train_step(trainer, 0, inputs, callback)
         assert completed
 
+    @pytest.mark.parametrize('autocast', [True, False])
+    def test_autocast(self, autocast):
+        self.run_autocast({'autocast': autocast})
+
     def test_autocast_not_enabled(self):
-        old_enable = ppe.handler._logic._amp_enabled
+        old_enable = ppe.runtime._autocast._cuda_amp_available
         try:
-            ppe.handler._logic._amp_enabled = False
+            ppe.runtime._autocast._cuda_amp_available = False
             with pytest.raises(RuntimeError):
                 ppe.handler.Logic(options={'autocast': True})
         finally:
-            ppe.handler._logic._amp_enabled = old_enable
+            ppe.runtime._autocast._cuda_amp_available = old_enable
+
+    @pytest.mark.skipif(not ppe.requires("1.10.0"), reason="requires PyTorch>=1.10")
+    @pytest.mark.parametrize(
+        'device_type, dtype',
+        [("cpu", torch.bfloat16), ("cuda", torch.float16)]
+    )
+    def test_autocast_options(self, device_type, dtype):
+        self.run_autocast(
+            {"autocast": {'device_type': device_type, "dtype": dtype}}
+        )
 
 
 class TestLogic:
@@ -497,14 +523,14 @@ class TestLogic:
 
     @pytest.mark.gpu
     def test_disabled_grad_scaler(self):
-        old_enable = ppe.handler._logic._amp_enabled
+        old_enable = ppe.runtime._autocast._cuda_amp_available
         try:
-            ppe.handler._logic._amp_enabled = False
+            ppe.runtime._autocast._cuda_amp_available = False
             options = {'grad_scaler': torch.cuda.amp.GradScaler()}
             with pytest.raises(RuntimeError):
                 ppe.handler.Logic(options=options)
         finally:
-            ppe.handler._logic._amp_enabled = old_enable
+            ppe.runtime._autocast._cuda_amp_available = old_enable
 
     def test_train_validation_begin(self):
         logic = ppe.handler.Logic()
@@ -522,3 +548,9 @@ class TestLogic:
         models['main'].eval()
         out = logic.eval_step(models, 0, input)
         torch_testing_assert_close(out, model(input))
+
+    @pytest.mark.gpu
+    def test_use_grad_scaler_with_clousure(self):
+        options = {'grad_scaler': torch.cuda.amp.GradScaler()}
+        with pytest.raises(RuntimeError):
+            ppe.handler.ClousureLogic(options=options)
