@@ -171,6 +171,15 @@ def test_report_tensor_detached():
     assert x.requires_grad
 
 
+def test_report_callable():
+    reporter = ppe.reporting.Reporter()
+    with reporter:
+        ppe.reporting.report({"x": lambda: 1.0})
+    observation = reporter.observation
+    assert "x" in observation
+    assert callable(observation["x"])
+
+
 # ppe.reporting.Summary
 
 def test_summary_basic():
@@ -225,6 +234,34 @@ def test_summary_weight():
     numpy.testing.assert_allclose(mean.numpy(), val)
 
 
+def test_summary_deferred_add():
+    summary = ppe.reporting.Summary()
+    summary.add(lambda: 1.0)
+    assert summary._n == 0
+    assert len(summary._deferred) == 1
+    assert summary.compute_mean() == 1.0
+
+
+def test_summary_add_operator():
+    s1 = ppe.reporting.Summary()
+    s1.add(1.)
+    s1.add(2.)
+    s1.add(3.)
+
+    s2 = ppe.reporting.Summary()
+    s2.add(4.)
+    s2.add(5.)
+    s2.add(6.)
+    s2.add(7.)
+
+    s = s1 + s2
+    assert s.state_dict() == {
+        '_x': 28.0,
+        '_x2': 140.0,
+        '_n': 7,
+    }
+
+
 def _nograd(v):
     if isinstance(v, torch.Tensor):
         return v.detach()
@@ -296,6 +333,7 @@ def test_serialize_tensor():
         torch.tensor(3.5))
 
 
+@pytest.mark.gpu
 def test_serialize_tensor_cuda():
     _check_summary_serialize(
         torch.tensor(1.5).cuda(),
@@ -464,3 +502,33 @@ def test_serialize_overwrite_rollback():
         'b': (1., 5., 5.),
         'c': (8.,),
     })
+
+
+def test_dict_summary_deferred_add():
+    summary = ppe.reporting.DictSummary()
+    summary.add({"x": lambda: 1.0, "y": lambda: 2.0})
+    summary.add({"x": lambda: -1.0})
+
+    _check_dict_summary(summary, {
+        "x": (1.0, -1.0),
+        "y": (2.0,),
+    })
+
+
+def test_dict_summary_add_operator():
+    s1 = ppe.reporting.DictSummary()
+    s1.add({'a': 1., 'b': 0.1, 'c': 0.01})
+    s1.add({'a': 2., 'b': 0.2, 'c': 0.02})
+
+    s2 = ppe.reporting.DictSummary()
+    s2.add({'a': 3., 'b': 0.3, 'f': 0.03})
+    s2.add({'a': 4., 'b': 0.4, 'f': 0.04})
+    s2.add({'a': 5., 'b': 0.5, 'f': 0.05})
+
+    s = s1 + s2
+    _check_dict_summary(s, {
+        'a': [1, 2, 3, 4, 5],
+        'b': [0.1, 0.2, 0.3, 0.4, 0.5],
+        'c': [0.01, 0.02],
+        'f': [0.03, 0.04, 0.05],
+    })
